/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kdnssd.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kdnssdadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KdnssdAdaptor
 */

KdnssdAdaptor::KdnssdAdaptor(DNSSDWatcher *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KdnssdAdaptor::~KdnssdAdaptor()
{
    // destructor
}

void KdnssdAdaptor::enteredDirectory(const QString &dir)
{
    // handle method call org.kde.kdnssd.enteredDirectory
    parent()->enteredDirectory(dir);
}

void KdnssdAdaptor::leftDirectory(const QString &dir)
{
    // handle method call org.kde.kdnssd.leftDirectory
    parent()->leftDirectory(dir);
}

QStringList KdnssdAdaptor::watchedDirectories()
{
    // handle method call org.kde.kdnssd.watchedDirectories
    return parent()->watchedDirectories();
}


#include "moc_kdnssdadaptor.cpp"
